@@ -9,7 +9,7 @@ from ConfigParser import SafeConfigParser
 import dbus
 from dbus.mainloop.glib import DBusGMainLoop
 
-version = "2.1-0"
+version = "2.1-1"
 trackingEnabled = True
 stopTracking = True
 stopWhenIdle = False
@@ -541,7 +541,7 @@ class Window(object):
             self.buttonShowRestart.set_sensitive(False)
             self.buttonShowSettings.set_sensitive(False)
             if showSettingsButton:
-                self.printDialog("Settings can be accessed by opening 'OSW Options' from the application menu, category desktop.")
+                self.printDialog("Settings can be accessed by opening 'OSW Options' in the application menu, category desktop.")
         self.parser.set('options', 'confirmDisconnect', str(confirmDisconnect))
         self.write_config()
         system("dbus-send --type=signal / org.maemo.oswoptions.changed1 string:'confirmDisconnect' string:'"+str(confirmDisconnect)+"'")
@@ -557,7 +557,7 @@ class Window(object):
         global showSettingsButton
         showSettingsButton = not showSettingsButton
         if not showSettingsButton:
-            self.printDialog("Settings can be accessed by opening 'OSW Options' from the application menu, category desktop.")
+            self.printDialog("Settings can be accessed by opening 'OSW Options' in the application menu, category desktop.")
         self.parser.set('options', 'showSettingsButton', str(showSettingsButton))
         self.write_config()
         system("dbus-send --type=signal / org.maemo.oswoptions.changed1 string:'showSettingsButton' string:'"+str(showSettingsButton)+"'")
