@@ -538,8 +538,8 @@ class opensshStatus(StatusMenuItem):
         self.get_toplevel().hide()
         system("sudo openssh-status.sh wifipmoff_once")
         
-        self.sshUsers()
-        if self.sshConnected == 0:
+        #self.sshUsers()
+        if int(getoutput("ps aux | grep ssh | grep -v grep | grep -c @")) == 0:
             self.printInfo("Wifi PM is kept off for 30 sec.\nGood time to log in...")
         else:
             keepWifiPMOff = False
@@ -806,7 +806,7 @@ class opensshStatus(StatusMenuItem):
                 buttonDisconnectRestart.set_label('  Disconnect\nRestart server')
             if not self.trackingEnabled:
                 buttonConnected = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
-                buttonConnected.set_label('Connections')
+                buttonConnected.set_label('Server connections')
                 if self.sshConnected == 1:
                     self.printInfo("1 connection")
                 else:
@@ -871,7 +871,7 @@ class opensshStatus(StatusMenuItem):
             if self.sshRunning:
                 self.printDialog("Could NOT stop OpenSSH Server !")
             elif self.sshConnected:
-                self.printDialog("Could NOT close OpenSSH connections!")
+                self.printDialog("Could NOT close OpenSSH server connections!")
             else:
                 self.on = False
                 self.labelConnected = 0
@@ -884,7 +884,7 @@ class opensshStatus(StatusMenuItem):
             time.sleep(1)
             self.sshUsers()
             if self.sshConnected:
-                self.printDialog("Could NOT close OpenSSH connections!")
+                self.printDialog("Could NOT close OpenSSH server connections!")
             else:
                 self.on = False
                 self.labelConnected = 0
@@ -904,7 +904,7 @@ class opensshStatus(StatusMenuItem):
             if self.sshRunning:
                 self.printDialog("Could NOT restart OpenSSH Server !")
             elif self.sshConnected:
-                self.printDialog("Could NOT close OpenSSH connections!")
+                self.printDialog("Could NOT close OpenSSH server connections!")
             else:
                 system("sudo openssh-status.sh start_sshd")
                 if self.trackingEnabled:
@@ -917,7 +917,7 @@ class opensshStatus(StatusMenuItem):
             time.sleep(1)
             self.sshUsers()
             if self.sshConnected:
-                self.printDialog("Could NOT close OpenSSH connections!")
+                self.printDialog("Could NOT close OpenSSH server connections!")
             else:
                 system("sudo openssh-status.sh start_sshd")
                 if self.trackingEnabled:
