@@ -41,7 +41,8 @@ if [ "$1" = "enable_wifipmoff" ] ; then
 fi
 
 if [ "$1" = "disconnect" ] ; then
-        if [ $(ps aux | grep -v grep  | grep -c /usr/lib/openssh/wifi-power-management\ once) = "0" ]; then
+        if [ $(ps aux | grep -v grep  | grep -c /usr/lib/openssh/wifi-power-management\ once) = "0" ] \
+        && [ $(ps aux | grep ssh | grep -c @) = "0" ]; then
           kill $(ps aux | grep /usr/lib/openssh/wifi-power-management | grep -v grep | awk '{print $1}')
           iwconfig wlan0 power on
         fi
